@@ -559,7 +559,7 @@ def ReadStudy(filepath: str, study_parameters: Union[list,tuple], nstudy: int =
                     MSE_test.append(np.array(G_study.get('mse_test')))
 
 
-                    if readPred:
+                    if read_pred:
                         Y_pred.append(np.array(G_study.get('y_pred')))
 
                 mse_train.append(MSE_train)
